// PIC16F18855 Configuration Bit Settings

// 'C' source line config statements

// CONFIG1
#pragma config FEXTOSC = OFF    // External Oscillator mode selection bits (Oscillator not enabled)
#pragma config RSTOSC = HFINT32 // Power-up default value for COSC bits (HFINTOSC with OSCFRQ= 32 MHz and CDIV = 1:1)
#pragma config CLKOUTEN = OFF   // Clock Out Enable bit (CLKOUT function is disabled; i/o or oscillator function on OSC2)
#pragma config CSWEN = ON       // Clock Switch Enable bit (Writing to NOSC and NDIV is allowed)
#pragma config FCMEN = ON       // Fail-Safe Clock Monitor Enable bit (FSCM timer enabled)

// CONFIG2
#pragma config MCLRE = ON       // Master Clear Enable bit (MCLR pin is Master Clear function)
#pragma config PWRTE = OFF      // Power-up Timer Enable bit (PWRT disabled)
#pragma config LPBOREN = OFF    // Low-Power BOR enable bit (ULPBOR disabled)
#pragma config BOREN = ON       // Brown-out reset enable bits (Brown-out Reset Enabled, SBOREN bit is ignored)
#pragma config BORV = LO        // Brown-out Reset Voltage Selection (Brown-out Reset Voltage (VBOR) set to 1.9V on LF, and 2.45V on F Devices)
#pragma config ZCD = OFF        // Zero-cross detect disable (Zero-cross detect circuit is disabled at POR.)
#pragma config PPS1WAY = ON     // Peripheral Pin Select one-way control (The PPSLOCK bit can be cleared and set only once in software)
#pragma config STVREN = ON      // Stack Overflow/Underflow Reset Enable bit (Stack Overflow or Underflow will cause a reset)

// CONFIG3
#pragma config WDTCPS = WDTCPS_31// WDT Period Select bits (Divider ratio 1:65536; software control of WDTPS)
#pragma config WDTE = OFF       // WDT operating mode (WDT Disabled, SWDTEN is ignored)
#pragma config WDTCWS = WDTCWS_7// WDT Window Select bits (window always open (100%); software control; keyed access not required)
#pragma config WDTCCS = SC      // WDT input clock selector (Software Control)

// CONFIG4
#pragma config WRT = OFF        // UserNVM self-write protection bits (Write protection off)
#pragma config SCANE = available// Scanner Enable bit (Scanner module is available for use)
#pragma config LVP = OFF        // Low Voltage Programming Enable bit (High Voltage on MCLR/Vpp must be used for programming)

// CONFIG5
#pragma config CP = OFF         // UserNVM Program memory code protection bit (Program Memory code protection disabled)
#pragma config CPD = OFF        // DataNVM code protection bit (Data EEPROM code protection disabled)

// #pragma config statements should precede project file includes.
// Use project enums instead of #define for ON and OFF.

#define _XTAL_FREQ 16000000
#include "xc.h"

void main(void) {
    
//    OSCCON1bits.NOSC = 0X06; //ESTABLECE EL OSCILADOR COMO INTERNO 
//    OSCCON1bits.NDIV = 0x01; //DIVIDE EL OSCILADOR EN 2   
    OSCFRQbits.HFFRQ = 0X05;   //CONFIGURA EL OSCILADOR INTERNO A 16 MHz
    
    TRISAbits.TRISA0 = 0; //CONFIGURA EL PIN A0 COMO SALIDA 
    TRISAbits.TRISA1 = 0; //CONFIGURA EL PIN A1 COMO SALIDA 
    TRISAbits.TRISA2 = 0; //CONFIGURA EL PIN A2 COMO SALIDA
    TRISAbits.TRISA3 = 0; //CONFIGURA EL PIN A3 COMO SALIDA 
    
    LATAbits.LATA0 = 0; //ESTABLECE EL PIN A0 EN ESTADO "BAJO"
    LATAbits.LATA1 = 0; //ESTABLECE EL PIN A1 EN ESTADO "BAJO"
    LATAbits.LATA2 = 0; //ESTABLECE EL PIN A2 EN ESTADO "BAJO"
    LATAbits.LATA3 = 0; //ESTABLECE EL PIN A3 EN ESTADO "BAJO"
    
    while(1)
    {
        LATAbits.LATA0 = 1; // Enciende el led conectado al pin A0
        __delay_ms(200); 
        LATAbits.LATA1 = 1; // Enciende el led conectado al pin A1
        __delay_ms(200); 
        LATAbits.LATA2 = 1; // Enciende el led conectado al pin A2
        __delay_ms(200); 
        LATAbits.LATA3 = 1; // Enciende el led conectado al pin A3
        __delay_ms(200); 
        LATAbits.LATA0 = 0; // Apaga el led conectado al pin A0
        __delay_ms(200); 
        LATAbits.LATA1 = 0; // Apaga el led conectado al pin A1
        __delay_ms(200); 
        LATAbits.LATA2 = 0; // Apaga el led conectado al pin A2
        __delay_ms(200); 
        LATAbits.LATA3 = 0; // Apaga el led conectado al pin A3
        __delay_ms(200);  
    }
}